@@ -25,20 +25,20 @@ DEFAULT_BASE_TAGS = {
     'centos': '8',
     'rhel': '8',
     'debian': '10',
-    'ubuntu': '18.04',
+    'ubuntu': '20.04',
 }
 DISTRO_RELEASE = {
     'centos': '8',
     'rhel': '8',
     'debian': '10',
-    'ubuntu': '18.04',
+    'ubuntu': '20.04',
 }
-OPENSTACK_RELEASE = 'ussuri'
+OPENSTACK_RELEASE = 'victoria'
 
 # This is noarch repository so we will use it on all architectures
-DELOREAN = "https://trunk.rdoproject.org/centos8-ussuri/" \
+DELOREAN = "https://trunk.rdoproject.org/centos8-master/" \
     "consistent/delorean.repo"
-DELOREAN_DEPS = "https://trunk.rdoproject.org/centos8-ussuri/" \
+DELOREAN_DEPS = "https://trunk.rdoproject.org/centos8-master/" \
     "delorean-deps.repo"
 
 INSTALL_TYPE_CHOICES = ['binary', 'source', 'rdo', 'rhos']
@@ -63,8 +63,6 @@ _PROFILE_OPTS = [
                     'logstash',
                     'mariadb',
                     'memcached',
-                    'mongodb',
-                    'opendaylight',
                     'openvswitch',
                     'ptp',
                     'qdrouterd',
@@ -96,7 +94,6 @@ _PROFILE_OPTS = [
                     'aodh',
                     'blazar',
                     'cloudkitty',
-                    'congress',
                     'designate',
                     'ec2-api',
                     'freezer',
@@ -198,9 +195,8 @@ _CLI_OPTS = [
     cfg.BoolOpt('push', default=False,
                 help='Push images after building'),
     cfg.IntOpt('push-threads', default=1, min=1,
-               help=('The number of threads to user while pushing'
-                     ' Images. Note: Docker can not handle threading'
-                     ' push properly')),
+               help=('The number of threads to use while pushing images.'
+                     ' Note: Docker cannot handle threaded pushing properly')),
     cfg.IntOpt('retries', short='r', default=3, min=0,
                help='The number of times to retry while building'),
     cfg.MultiOpt('regex', types.String(), positional=True, required=False,
@@ -255,7 +251,11 @@ _CLI_OPTS = [
     cfg.BoolOpt('quiet', short='q', default=False,
                 help='Do not print image logs'),
     cfg.BoolOpt('enable-unbuildable', default=False,
-                help='Enable images marked as unbuildable')
+                help='Enable images marked as unbuildable'),
+    cfg.BoolOpt('summary', default=True,
+                help='Show summary at the end of build'),
+    cfg.BoolOpt('infra-rename', default=False,
+                help='Rename infrastructure images to infra')
 ]
 
 _BASE_OPTS = [
@@ -289,67 +289,63 @@ SOURCES = {
     'openstack-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/requirements/'
-                     'requirements-stable-ussuri.tar.gz')},
+                     'requirements-stable-victoria.tar.gz')},
     'aodh-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/aodh/'
-                     'aodh-stable-ussuri.tar.gz')},
+                     'aodh-stable-victoria.tar.gz')},
     'barbican-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/barbican/'
-                     'barbican-stable-ussuri.tar.gz')},
+                     'barbican-stable-victoria.tar.gz')},
     'bifrost-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/bifrost/'
-                     'bifrost-stable-ussuri.tar.gz')},
+                     'bifrost-stable-victoria.tar.gz')},
     'blazar-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/blazar/'
-                     'blazar-stable-ussuri.tar.gz')},
+                     'blazar-stable-victoria.tar.gz')},
     'ceilometer-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/ceilometer/'
-                     'ceilometer-stable-ussuri.tar.gz')},
+                     'ceilometer-stable-victoria.tar.gz')},
     'ceilometer-base-plugin-panko': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/panko/'
-                     'panko-stable-ussuri.tar.gz')},
+                     'panko-stable-victoria.tar.gz')},
     'cinder-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/cinder/'
-                     'cinder-stable-ussuri.tar.gz')},
-    'congress-base': {
-        'type': 'url',
-        'location': ('$tarballs_base/openstack/congress/'
-                     'congress-stable-ussuri.tar.gz')},
+                     'cinder-stable-victoria.tar.gz')},
     'cloudkitty-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/cloudkitty/'
-                     'cloudkitty-stable-ussuri.tar.gz')},
+                     'cloudkitty-stable-victoria.tar.gz')},
     'cyborg-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/cyborg/'
-                     'cyborg-stable-ussuri.tar.gz')},
+                     'cyborg-stable-victoria.tar.gz')},
     'designate-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/designate/'
-                     'designate-stable-ussuri.tar.gz')},
+                     'designate-stable-victoria.tar.gz')},
     'ec2-api': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/ec2-api/'
-                     'ec2-api-stable-ussuri.tar.gz')},
+                     'ec2-api-stable-victoria.tar.gz')},
     'freezer-api': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/freezer-api/'
-                     'freezer-api-stable-ussuri.tar.gz')},
+                     'freezer-api-stable-victoria.tar.gz')},
     'freezer-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/freezer/'
-                     'freezer-stable-ussuri.tar.gz')},
+                     'freezer-stable-victoria.tar.gz')},
     'glance-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/glance/'
-                     'glance-stable-ussuri.tar.gz')},
+                     'glance-stable-victoria.tar.gz')},
     'gnocchi-base': {
         'type': 'git',
         'reference': '4.3.4',
@@ -358,280 +354,252 @@ SOURCES = {
     'heat-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/heat/'
-                     'heat-stable-ussuri.tar.gz')},
+                     'heat-stable-victoria.tar.gz')},
     'horizon': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/horizon/'
-                     'horizon-stable-ussuri.tar.gz')},
+                     'horizon-stable-victoria.tar.gz')},
     'horizon-plugin-blazar-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/blazar-dashboard/'
-                     'blazar-dashboard-stable-ussuri.tar.gz')},
-    'horizon-plugin-congress-dashboard': {
-        'type': 'url',
-        'location': ('$tarballs_base/openstack/congress-dashboard/'
-                     'congress-dashboard-stable-ussuri.tar.gz')},
+                     'blazar-dashboard-stable-victoria.tar.gz')},
     'horizon-plugin-cloudkitty-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/cloudkitty-dashboard/'
-                     'cloudkitty-dashboard-stable-ussuri.tar.gz')},
+                     'cloudkitty-dashboard-stable-victoria.tar.gz')},
     'horizon-plugin-designate-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/designate-dashboard/'
-                     'designate-dashboard-stable-ussuri.tar.gz')},
-    'horizon-plugin-fwaas-dashboard': {
-        'type': 'url',
-        'location': ('$tarballs_base/openstack/neutron-fwaas-dashboard/'
-                     'neutron-fwaas-dashboard-stable-ussuri.tar.gz')},
+                     'designate-dashboard-stable-victoria.tar.gz')},
     'horizon-plugin-freezer-web-ui': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/freezer-web-ui/'
-                     'freezer-web-ui-stable-ussuri.tar.gz')},
+                     'freezer-web-ui-stable-victoria.tar.gz')},
     'horizon-plugin-heat-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/heat-dashboard/'
-                     'heat-dashboard-stable-ussuri.tar.gz')},
+                     'heat-dashboard-stable-victoria.tar.gz')},
     'horizon-plugin-ironic-ui': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/ironic-ui/'
-                     'ironic-ui-stable-ussuri.tar.gz')},
+                     'ironic-ui-stable-victoria.tar.gz')},
     'horizon-plugin-karbor-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/karbor-dashboard/'
-                     'karbor-dashboard-stable-ussuri.tar.gz')},
+                     'karbor-dashboard-stable-victoria.tar.gz')},
     'horizon-plugin-magnum-ui': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/magnum-ui/'
-                     'magnum-ui-stable-ussuri.tar.gz')},
+                     'magnum-ui-stable-victoria.tar.gz')},
     'horizon-plugin-manila-ui': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/manila-ui/'
-                     'manila-ui-stable-ussuri.tar.gz')},
+                     'manila-ui-stable-victoria.tar.gz')},
     'horizon-plugin-masakari-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/masakari-dashboard/'
-                     'masakari-dashboard-stable-ussuri.tar.gz')},
+                     'masakari-dashboard-stable-victoria.tar.gz')},
     'horizon-plugin-mistral-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/mistral-dashboard/'
-                     'mistral-dashboard-stable-ussuri.tar.gz')},
+                     'mistral-dashboard-stable-victoria.tar.gz')},
     'horizon-plugin-monasca-ui': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/monasca-ui/'
-                     'monasca-ui-stable-ussuri.tar.gz')},
+                     'monasca-ui-stable-victoria.tar.gz')},
     'horizon-plugin-murano-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/murano-dashboard/'
-                     'murano-dashboard-stable-ussuri.tar.gz')},
+                     'murano-dashboard-stable-victoria.tar.gz')},
     'horizon-plugin-neutron-vpnaas-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/neutron-vpnaas-dashboard/'
-                     'neutron-vpnaas-dashboard-stable-ussuri.tar.gz')},
+                     'neutron-vpnaas-dashboard-stable-victoria.tar.gz')},
     'horizon-plugin-octavia-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/octavia-dashboard/'
-                     'octavia-dashboard-stable-ussuri.tar.gz')},
+                     'octavia-dashboard-stable-victoria.tar.gz')},
     'horizon-plugin-qinling-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/qinling-dashboard/'
-                     'qinling-dashboard-stable-ussuri.tar.gz')},
+                     'qinling-dashboard-stable-victoria.tar.gz')},
     'horizon-plugin-sahara-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/sahara-dashboard/'
-                     'sahara-dashboard-stable-ussuri.tar.gz')},
+                     'sahara-dashboard-stable-victoria.tar.gz')},
     'horizon-plugin-searchlight-ui': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/searchlight-ui/'
-                     'searchlight-ui-stable-ussuri.tar.gz')},
+                     'searchlight-ui-stable-victoria.tar.gz')},
     'horizon-plugin-senlin-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/senlin-dashboard/'
-                     'senlin-dashboard-stable-ussuri.tar.gz')},
+                     'senlin-dashboard-stable-victoria.tar.gz')},
     'horizon-plugin-solum-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/solum-dashboard/'
-                     'solum-dashboard-stable-ussuri.tar.gz')},
+                     'solum-dashboard-stable-victoria.tar.gz')},
     'horizon-plugin-tacker-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/tacker-horizon/'
-                     'tacker-horizon-stable-ussuri.tar.gz')},
+                     'tacker-horizon-stable-victoria.tar.gz')},
     'horizon-plugin-trove-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/trove-dashboard/'
-                     'trove-dashboard-stable-ussuri.tar.gz')},
+                     'trove-dashboard-stable-victoria.tar.gz')},
     'horizon-plugin-vitrage-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/vitrage-dashboard/'
-                     'vitrage-dashboard-stable-ussuri.tar.gz')},
+                     'vitrage-dashboard-stable-victoria.tar.gz')},
     'horizon-plugin-watcher-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/watcher-dashboard/'
-                     'watcher-dashboard-stable-ussuri.tar.gz')},
+                     'watcher-dashboard-stable-victoria.tar.gz')},
     'horizon-plugin-zaqar-ui': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/zaqar-ui/'
-                     'zaqar-ui-stable-ussuri.tar.gz')},
+                     'zaqar-ui-stable-victoria.tar.gz')},
     'horizon-plugin-zun-ui': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/zun-ui/'
-                     'zun-ui-stable-ussuri.tar.gz')},
+                     'zun-ui-stable-victoria.tar.gz')},
     'ironic-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/ironic/'
-                     'ironic-stable-ussuri.tar.gz')},
+                     'ironic-stable-victoria.tar.gz')},
     'ironic-inspector': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/ironic-inspector/'
-                     'ironic-inspector-stable-ussuri.tar.gz')},
+                     'ironic-inspector-stable-victoria.tar.gz')},
     'karbor-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/karbor/'
-                     'karbor-stable-ussuri.tar.gz')},
+                     'karbor-stable-victoria.tar.gz')},
     'keystone-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/keystone/'
-                     'keystone-stable-ussuri.tar.gz')},
+                     'keystone-stable-victoria.tar.gz')},
     'kuryr-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/kuryr/'
-                     'kuryr-stable-ussuri.tar.gz')},
+                     'kuryr-stable-victoria.tar.gz')},
     'kuryr-libnetwork': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/kuryr-libnetwork/'
-                     'kuryr-libnetwork-stable-ussuri.tar.gz')},
+                     'kuryr-libnetwork-stable-victoria.tar.gz')},
     'magnum-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/magnum/'
-                     'magnum-stable-ussuri.tar.gz')},
+                     'magnum-stable-victoria.tar.gz')},
     'manila-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/manila/'
-                     'manila-stable-ussuri.tar.gz')},
+                     'manila-stable-victoria.tar.gz')},
     'masakari-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/masakari/'
-                     'masakari-stable-ussuri.tar.gz')},
+                     'masakari-stable-victoria.tar.gz')},
     'masakari-monitors': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/masakari-monitors/'
-                     'masakari-monitors-stable-ussuri.tar.gz')},
+                     'masakari-monitors-stable-victoria.tar.gz')},
     'mistral-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/mistral/'
-                     'mistral-stable-ussuri.tar.gz')},
+                     'mistral-stable-victoria.tar.gz')},
     'mistral-base-plugin-tacker': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/tacker/'
-                     'tacker-stable-ussuri.tar.gz')},
+                     'tacker-stable-victoria.tar.gz')},
     'monasca-agent': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/monasca-agent/'
-                     'monasca-agent-stable-ussuri.tar.gz')},
+                     'monasca-agent-stable-victoria.tar.gz')},
     'monasca-api': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/monasca-api/'
-                     'monasca-api-stable-ussuri.tar.gz')},
+                     'monasca-api-stable-victoria.tar.gz')},
     'monasca-notification': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/monasca-notification/'
-                     'monasca-notification-stable-ussuri.tar.gz')},
+                     'monasca-notification-stable-victoria.tar.gz')},
     'monasca-persister': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/monasca-persister/'
-                     'monasca-persister-stable-ussuri.tar.gz')},
+                     'monasca-persister-stable-victoria.tar.gz')},
     'monasca-statsd': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/monasca-statsd/'
-                     'monasca-statsd-stable-ussuri.tar.gz')},
+                     'monasca-statsd-stable-victoria.tar.gz')},
     # FIXME(dszumski): Use openstack tar when infra is fixed
     'monasca-thresh': {
         'type': 'url',
         'location': ('https://github.com/openstack/monasca-thresh/archive/'
-                     '2.7.0.tar.gz')},
+                     'stable/victoria.tar.gz')},
     'monasca-thresh-additions-monasca-common': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/monasca-common/'
-                     'monasca-common-stable-ussuri.tar.gz')},
+                     'monasca-common-stable-victoria.tar.gz')},
     'murano-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/murano/'
-                     'murano-stable-ussuri.tar.gz')},
+                     'murano-stable-victoria.tar.gz')},
     'neutron-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/neutron/'
-                     'neutron-stable-ussuri.tar.gz')},
-    'neutron-base-plugin-neutron-fwaas': {
-        'type': 'url',
-        'location': ('$tarballs_base/openstack/neutron-fwaas/'
-                     'neutron-fwaas-stable-ussuri.tar.gz')},
+                     'neutron-stable-victoria.tar.gz')},
     'neutron-base-plugin-networking-ansible': {
         'type': 'url',
         'location': ('$tarballs_base/x/networking-ansible/'
-                     'networking-ansible-stable-ussuri.tar.gz')},
+                     'networking-ansible-master.tar.gz')},
     'neutron-base-plugin-networking-baremetal': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/networking-baremetal/'
-                     'networking-baremetal-stable-ussuri.tar.gz')},
+                     'networking-baremetal-stable-victoria.tar.gz')},
     'neutron-base-plugin-networking-generic-switch': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/networking-generic-switch/'
-                     'networking-generic-switch-stable-ussuri.tar.gz')},
+                     'networking-generic-switch-stable-victoria.tar.gz')},
     'neutron-base-plugin-networking-mlnx': {
         'type': 'url',
         'location': ('$tarballs_base/x/networking-mlnx/'
-                     'networking-mlnx-stable-ussuri.tar.gz')},
+                     'networking-mlnx-stable-victoria.tar.gz')},
     'neutron-base-plugin-networking-sfc': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/networking-sfc/'
-                     'networking-sfc-stable-ussuri.tar.gz')},
+                     'networking-sfc-stable-victoria.tar.gz')},
     'neutron-base-plugin-vmware-nsx': {
         'type': 'url',
         'location': ('$tarballs_base/x/vmware-nsx/'
-                     'vmware-nsx-16.0.0.tar.gz')},
+                     'vmware-nsx-master.tar.gz')},
     'neutron-base-plugin-vpnaas-agent': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/neutron-vpnaas/'
-                     'neutron-vpnaas-stable-ussuri.tar.gz')},
+                     'neutron-vpnaas-stable-victoria.tar.gz')},
     'neutron-bgp-dragent': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/neutron-dynamic-routing/'
-                     'neutron-dynamic-routing-stable-ussuri.tar.gz')},
-    'neutron-server-opendaylight-plugin-networking-odl': {
-        'type': 'url',
-        'location': ('$tarballs_base/openstack/networking-odl/'
-                     'networking-odl-stable-ussuri.tar.gz')},
-    'neutron-server-opendaylight-plugin-networking-bgpvpn': {
-        'type': 'url',
-        'location': ('$tarballs_base/openstack/networking-bgpvpn/'
-                     'networking-bgpvpn-stable-ussuri.tar.gz')},
-    'neutron-server-opendaylight-plugin-networking-l2gw': {
-        'type': 'url',
-        'location': ('$tarballs_base/openstack/networking-l2gw/'
-                     'networking-l2gw-stable-ussuri.tar.gz')},
-    'neutron-server-opendaylight-plugin-networking-sfc': {
-        'type': 'url',
-        'location': ('$tarballs_base/openstack/networking-sfc/'
-                     'networking-sfc-stable-ussuri.tar.gz')},
+                     'neutron-dynamic-routing-stable-victoria.tar.gz')},
     'neutron-server-plugin-neutron-dynamic-routing': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/neutron-dynamic-routing/'
-                     'neutron-dynamic-routing-stable-ussuri.tar.gz')},
+                     'neutron-dynamic-routing-stable-victoria.tar.gz')},
     'neutron-server-plugin-vmware-nsxlib': {
         'type': 'url',
         'location': ('$tarballs_base/x/vmware-nsxlib/'
-                     'vmware-nsxlib-stable-ussuri.tar.gz')},
+                     'vmware-nsxlib-master.tar.gz')},
     'neutron-vpnaas-agent': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/neutron-vpnaas/'
-                     'neutron-vpnaas-stable-ussuri.tar.gz')},
+                     'neutron-vpnaas-stable-victoria.tar.gz')},
     'nova-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/nova/'
-                     'nova-stable-ussuri.tar.gz')},
+                     'nova-stable-victoria.tar.gz')},
     'nova-base-plugin-blazar': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/blazar-nova/'
-                     'blazar-nova-stable-ussuri.tar.gz')},
+                     'blazar-nova-stable-victoria.tar.gz')},
     'nova-base-plugin-mksproxy': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/nova-mksproxy/'
@@ -643,183 +611,175 @@ SOURCES = {
     'octavia-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/octavia/'
-                     'octavia-stable-ussuri.tar.gz')},
+                     'octavia-stable-victoria.tar.gz')},
     'octavia-api-plugin-ovn-octavia-provider': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/ovn-octavia-provider/'
-                     'ovn-octavia-provider-stable-ussuri.tar.gz')},
+                     'ovn-octavia-provider-stable-victoria.tar.gz')},
     'panko-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/panko/'
-                     'panko-stable-ussuri.tar.gz')},
+                     'panko-stable-victoria.tar.gz')},
     'placement-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/placement/'
-                     'placement-stable-ussuri.tar.gz')},
+                     'placement-stable-victoria.tar.gz')},
     'qinling-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/qinling/'
-                     'qinling-stable-ussuri.tar.gz')},
+                     'qinling-stable-victoria.tar.gz')},
     'tempest-plugin-tempest-conf': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/python-tempestconf/'
-                     'python-tempestconf-2.5.0.tar.gz')},
+                     'python-tempestconf-master.tar.gz')},
     'tempest-plugin-barbican': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/barbican-tempest-plugin/'
-                     'barbican_tempest_plugin-1.0.0.tar.gz')},
+                     'barbican_tempest_plugin-1.1.0.tar.gz')},
     'tempest-plugin-blazar': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/blazar-tempest-plugin/'
-                     'blazar_tempest_plugin-0.4.0.tar.gz')},
+                     'blazar_tempest_plugin-0.5.0.tar.gz')},
     'tempest-plugin-cinder': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/cinder-tempest-plugin/'
-                     'cinder-tempest-plugin-1.0.0.tar.gz')},
-    'tempest-plugin-congress': {
-        'type': 'url',
-        'location': ('$tarballs_base/openstack/congress-tempest-plugin/'
-                     'congress-tempest-plugin-1.0.0.tar.gz')},
+                     'cinder-tempest-plugin-1.2.0.tar.gz')},
     'tempest-plugin-ec2api': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/ec2api-tempest-plugin/'
-                     'ec2api-tempest-plugin-1.0.0.tar.gz')},
+                     'ec2api-tempest-plugin-1.1.0.tar.gz')},
     'tempest-plugin-heat': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/heat-tempest-plugin/'
-                     'heat-tempest-plugin-1.0.0.tar.gz')},
+                     'heat-tempest-plugin-1.1.0.tar.gz')},
     'tempest-plugin-ironic': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/ironic-tempest-plugin/'
-                     'ironic-tempest-plugin-2.0.0.tar.gz')},
+                     'ironic-tempest-plugin-2.1.0.tar.gz')},
     'tempest-plugin-keystone': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/keystone-tempest-plugin/'
-                     'keystone_tempest_plugin-0.4.0.tar.gz')},
+                     'keystone_tempest_plugin-0.5.0.tar.gz')},
     'tempest-plugin-magnum': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/magnum-tempest-plugin/'
-                     'magnum_tempest_plugin-1.0.0.tar.gz')},
+                     'magnum_tempest_plugin-1.1.0.tar.gz')},
     'tempest-plugin-manila': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/manila-tempest-plugin/'
-                     'manila-tempest-plugin-1.0.0.tar.gz')},
+                     'manila-tempest-plugin-1.2.0.tar.gz')},
     'tempest-plugin-mistral': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/mistral-tempest-plugin/'
-                     'mistral_tempest_tests-1.0.0.tar.gz')},
+                     'mistral_tempest_tests-1.1.0.tar.gz')},
     'tempest-plugin-monasca': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/monasca-tempest-plugin/'
-                     'monasca-tempest-plugin-2.0.0.tar.gz')},
+                     'monasca-tempest-plugin-2.1.0.tar.gz')},
     'tempest-plugin-murano': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/murano-tempest-plugin/'
-                     'murano-tempest-plugin-2.0.0.tar.gz')},
+                     'murano-tempest-plugin-2.1.0.tar.gz')},
     'tempest-plugin-neutron': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/neutron-tempest-plugin/'
-                     'neutron-tempest-plugin-1.1.0.tar.gz')},
+                     'neutron-tempest-plugin-1.2.0.tar.gz')},
     'tempest-plugin-patrole': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/patrole/'
-                     'patrole-0.9.0.tar.gz')},
+                     'patrole-0.10.0.tar.gz')},
     'tempest-plugin-telemetry': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/telemetry-tempest-plugin/'
-                     'telemetry_tempest_plugin-1.0.0.tar.gz')},
+                     'telemetry_tempest_plugin-1.1.0.tar.gz')},
     'tempest-plugin-trove': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/trove-tempest-plugin/'
-                     'trove_tempest_plugin-1.0.0.tar.gz')},
+                     'trove_tempest_plugin-1.1.0.tar.gz')},
     'tempest-plugin-vitrage': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/vitrage-tempest-plugin/'
-                     'vitrage-tempest-plugin-4.0.0.tar.gz')},
+                     'vitrage-tempest-plugin-5.1.0.tar.gz')},
     'tempest-plugin-watcher': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/watcher-tempest-plugin/'
-                     'watcher-tempest-plugin-2.0.0.tar.gz')},
+                     'watcher-tempest-plugin-2.1.0.tar.gz')},
     'tempest-plugin-zaqar': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/zaqar-tempest-plugin/'
-                     'zaqar_tempest_plugin-1.0.0.tar.gz')},
+                     'zaqar_tempest_plugin-1.1.0.tar.gz')},
     'rally': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/rally/'
-                     'rally-3.2.0.tar.gz')},
+                     'rally-3.1.0.tar.gz')},
     'rally-plugin-openstack': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/rally-openstack/'
-                     'rally-openstack-2.1.0.tar.gz')},
+                     'rally-openstack-2.0.0.tar.gz')},
     'sahara-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/sahara/'
-                     'sahara-stable-ussuri.tar.gz')},
+                     'sahara-stable-victoria.tar.gz')},
     'sahara-base-plugin-ambari': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/sahara-plugin-ambari/'
-                     'sahara-plugin-ambari-stable-ussuri.tar.gz')},
+                     'sahara-plugin-ambari-stable-victoria.tar.gz')},
     'sahara-base-plugin-cdh': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/sahara-plugin-cdh/'
-                     'sahara-plugin-cdh-stable-ussuri.tar.gz')},
+                     'sahara-plugin-cdh-stable-victoria.tar.gz')},
     'sahara-base-plugin-mapr': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/sahara-plugin-mapr/'
-                     'sahara-plugin-mapr-stable-ussuri.tar.gz')},
+                     'sahara-plugin-mapr-stable-victoria.tar.gz')},
     'sahara-base-plugin-spark': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/sahara-plugin-spark/'
-                     'sahara-plugin-spark-stable-ussuri.tar.gz')},
+                     'sahara-plugin-spark-stable-victoria.tar.gz')},
     'sahara-base-plugin-storm': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/sahara-plugin-storm/'
-                     'sahara-plugin-storm-stable-ussuri.tar.gz')},
+                     'sahara-plugin-storm-stable-victoria.tar.gz')},
     'sahara-base-plugin-vanilla': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/sahara-plugin-vanilla/'
-                     'sahara-plugin-vanilla-stable-ussuri.tar.gz')},
+                     'sahara-plugin-vanilla-stable-victoria.tar.gz')},
     'searchlight-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/searchlight/'
-                     'searchlight-stable-ussuri.tar.gz')},
+                     'searchlight-stable-victoria.tar.gz')},
     'senlin-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/senlin/'
-                     'senlin-stable-ussuri.tar.gz')},
+                     'senlin-stable-victoria.tar.gz')},
     'solum-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/solum/'
-                     'solum-stable-ussuri.tar.gz')},
+                     'solum-stable-victoria.tar.gz')},
     'swift-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/swift/'
-                     'swift-stable-ussuri.tar.gz')},
+                     'swift-stable-victoria.tar.gz')},
     'tacker-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/tacker/'
-                     'tacker-stable-ussuri.tar.gz')},
+                     'tacker-stable-victoria.tar.gz')},
     'tacker-base-plugin-networking-sfc': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/networking-sfc/'
-                     'networking-sfc-stable-ussuri.tar.gz')},
+                     'networking-sfc-stable-victoria.tar.gz')},
     'tempest': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/tempest/'
-                     'tempest-24.0.0.tar.gz')},
-    'tripleoclient': {
-        'type': 'url',
-        'location': ('$tarballs_base/openstack/python-tripleoclient/'
-                     'tripleoclient-stable-ussuri.tar.gz')},
+                     'tempest-25.0.0.tar.gz')},
     'trove-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/trove/'
-                     'trove-stable-ussuri.tar.gz')},
+                     'trove-stable-victoria.tar.gz')},
     'vitrage-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/vitrage/'
-                     'vitrage-stable-ussuri.tar.gz')},
+                     'vitrage-stable-victoria.tar.gz')},
     'vmtp': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/vmtp/'
@@ -827,15 +787,15 @@ SOURCES = {
     'watcher-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/watcher/'
-                     'watcher-stable-ussuri.tar.gz')},
+                     'watcher-stable-victoria.tar.gz')},
     'zaqar-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/zaqar/'
-                     'zaqar-stable-ussuri.tar.gz')},
+                     'zaqar-stable-victoria.tar.gz')},
     'zun-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/zun/'
-                     'zun-stable-ussuri.tar.gz')}
+                     'zun-stable-victoria.tar.gz')}
 }
 
 
@@ -882,7 +842,7 @@ USERS = {
         'uid': 42409,
         'gid': 42409,
     },
-    'congress-user': {
+    'congress-user': {  # unused user (congress dropped)
         'uid': 42410,
         'gid': 42410,
     },
@@ -962,7 +922,7 @@ USERS = {
         'uid': 42431,
         'gid': 42431,
     },
-    'mongodb-user': {
+    'mongodb-user': {  # unused user (mongodb dropped)
         'uid': 42432,
         'gid': 65534,
     },
