@@ -55,7 +55,6 @@ ALWAYS_USE_VERSION_PROJECTS = {
     'barbican_tempest_plugin',
     'blazar_tempest_plugin',
     'cinder-tempest-plugin',
-    'congress-tempest-plugin',
     'ec2api-tempest-plugin',
     'heat-tempest-plugin',
     'ironic-tempest-plugin',
@@ -67,6 +66,7 @@ ALWAYS_USE_VERSION_PROJECTS = {
     'murano-tempest-plugin',
     'neutron-tempest-plugin',
     'python-tempestconf',
+    'rally-openstack',
     'telemetry_tempest_plugin',
     'patrole',
     'trove_tempest_plugin',
@@ -83,7 +83,6 @@ ALWAYS_USE_VERSION_PROJECTS = {
 # column) and other for branch tarballs
 RENAME_PROJECTS = {
     'kuryr-lib': 'kuryr',
-    'openstack-congress': 'congress',
     'openstack-cyborg': 'cyborg',
     'openstack-heat': 'heat',
     'openstack-placement': 'placement',
